inherit image

# The feature will install itself in whatever directory we ultimately
# expect it to appear as. Since we'll be mounting the UBI under part
# of that path we need to move everything up before it goes into the
# image. We also need to remove other random gubbins that we can't
# stop rootfs.py putting in the filesystem. The only file we let
# through is /etc/version just in case it's useful.
migrate_feature_to_root() {
    set -x
    rm -rf ${IMAGE_ROOTFS}/lib/modules ${IMAGE_ROOTFS}/var/lib/opkg
    rmdir ${IMAGE_ROOTFS}${sysconfdir}/rcS.d ${IMAGE_ROOTFS}/var/lib ${IMAGE_ROOTFS}/var
    
    find ${IMAGE_ROOTFS} -type f | sort > entire-contents.txt
    find ${IMAGE_ROOTFS}${FEATURE_PREFIX} ${IMAGE_ROOTFS}/etc/version -type f | sort > prefixed-contents.txt
    if ! cmp entire-contents.txt prefixed-contents.txt; then
        echo "Feature file system image contains unexpected files outside prefix"
        diff entire-contents.txt prefixed-contents.txt
        exit 1
    fi
    
    # Now move everything up to the root
    mv ${IMAGE_ROOTFS}${FEATURE_PREFIX}/* ${IMAGE_ROOTFS}
    
    # And remove the directories we left behind. This isn't really
    # generic but it should be sufficient for now.
    rmdir ${IMAGE_ROOTFS}${FEATURE_PREFIX} ${IMAGE_ROOTFS}/lib
    find ${IMAGE_ROOTFS}
}

# We only want the package we desire - no dependencies please
OPKG_ARGS += " --nodeps"

# We need to do this just before generating the image so that
# rootfs.py has finishe doing all is package-manager furtling etc.
IMAGE_PREPROCESS_COMMAND += "migrate_feature_to_root; "